==> haskell-clientsession-0.9.1.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
key: clientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: a206c0e9c9b4e999d42ac220e9329a5c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-4JSFAW5Er301EO5ypFfPZ3
    cprng-aes-0.6.1-ElzXuMli7WyAHsEinA5oq
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-JOU8lue6KbLEq1yW10dkyV directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-62CEysCoxT76hfvqp2op6A
key: clientsession-0.9.1.2-62CEysCoxT76hfvqp2op6A
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: 1334ea8d116b0accc294894239775d73
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-62CEysCoxT76hfvqp2op6A
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-3wSlYweYnOh5ki8DuHhTem
    cprng-aes-0.6.1-BU20aJJ9y5NAfagz6mZMjL
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-FuwPZ4h1SeNLOuc7iM0NM2 directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
